@@ -44,6 +44,7 @@ class Request(Resource):
             },
             "response": None,
             "exception": None,
+            "initiator": req.initiator.to_json(),
         }
 
         if req.response is not None:
@@ -94,9 +95,15 @@ class RequestContentUp(Resource):
     def get(self, req_id):
         req = get_request(req_id)
 
+        filename = os.path.basename(urlparse(req.request.url).path)
+
         return send_file(
-            io.BytesIO(req.request.body),
-            download_name="upload",
+            io.BytesIO(
+                req.request.body
+                if isinstance(req.request.body, bytes)
+                else bytes(req.request.body.encode("utf-8"))
+            ),
+            download_name=f"upload-{filename}",
             mimetype="application/octet-stream",
         )
 
@@ -115,7 +122,7 @@ class RequestList(Resource):
                 "status_code": req.status_code,
                 "reason": req.reason,
                 "verb": req.request.method,
-                "src": None if req.src is None else req.src.to_json(),
+                "initiator": req.initiator.to_json(full=False),
             }
 
         return k7
